@@ -2,12 +2,13 @@ from easy_pysy.utils.functional.dictionary import EzDict, K, V
 from easy_pysy.utils.functional.sequence import EzList, T
 from easy_pysy.utils.functional.function import bind, bind_all
 
+from typing import Iterable
+
 
 def magic(value: list[T] | dict[K, V]) -> EzList[T] | EzDict[K, V]:  # TODO: iterable/sequence
-    match value:
-        case list():
-            return EzList(value)
-        case dict():
-            return EzDict(value)
-        case _:
-            raise NotImplementedError(f'Unsupported magic: {type(value)}')
+    if isinstance(value, Iterable):
+        return EzList(value)
+    elif isinstance(value, dict):
+        return EzDict(value)
+    else:
+        raise NotImplementedError(f'Unsupported magic: {type(value)}')
